@@ -78,6 +78,10 @@ def agn_classifier(data):
 
     transformed_1, transformed_2, valid = fe.transform_data(converted, k.MINIMUM_POINTS)
 
+    all_empty = transformed_1.empty | transformed_2.empty
+    if all_empty:
+        return np.zeros(len(data), dtype=np.float)
+
     features_1 = fe.parametrise(transformed_1, 1)
     features_2 = fe.parametrise(transformed_2, 2)
 
