@@ -579,6 +579,13 @@ def merge_features(all_features, minimum_points, target_col=""):
     if target_col != "":
         ordered_features[target_col] = features[target_col]
 
+    # Make sure that no value is above 2**32 (scipy uses float32)
+    max_size = 2**30
+    float_cols = ordered_features.columns[ordered_features.columns != 'object_id']
+
+    ordered_features[float_cols] = ordered_features[float_cols].mask(ordered_features[float_cols] > max_size, max_size)
+    ordered_features[float_cols] = ordered_features[float_cols].mask(ordered_features[float_cols] < -max_size, -max_size)
+
     return ordered_features
 
 
@@ -607,6 +614,7 @@ def get_probabilities(clf, features, valid):
     final_proba = np.array([0.0] * len(valid)).astype(np.float64)
 
     if len(features) > 0:
+        features = features.replace(np.inf, 0.0).replace(np.nan, 0.0)
         agn_or_not = clf.predict_proba(features.iloc[:, 1:])
         index_to_replace = features.iloc[:, 1:].index
         final_proba[index_to_replace.values] = agn_or_not[:, 1]
